#!/bin/sh

# Bacup IP for debug via LAN
ifconfig eth0:1 192.168.2.20

# copy config from /boot with replace windows \r symbols
mount /boot > /dev/null 2>&1
cat /boot/cosmostreamer.conf | sed 's/\r$//' > /run/cosmostreamer.conf

. ./cosmostreamer.conf

# run HDMI display
if [ "$hdmi_enabled" = "1" ] ; then
    ./scripts/hdmi-change.sh 1 > /dev/null 2>&1 &
else
    ./scripts/hdmi-change.sh 0 > /dev/null 2>&1 &
fi

# check update file in /boot
UPDATE_FILENAME=`ls /boot/*.tar.gz 2>&1`
if [ "$?" = "0" ] ; then
    ./update.sh $UPDATE_FILENAME
fi

sysctl net.ipv4.udp_rmem_min=100000 >> /dev/null 2>&1
sysctl net.ipv4.udp_wmem_min=100000 >> /dev/null 2>&1

# add custom modules
insmod ./modules/8192eu.ko >> /dev/null 2>&1 # for D-link DWA-131


# start wlans manager
./scripts/wlan-switch.php &

# set audio capture volume
./scripts/audio-volume.sh $audio_volume > /dev/null 2>&1
./scripts/audio-gain.sh $audio_autogain > /dev/null 2>&1

# run audio capture
./scripts/loop-audio.sh > /dev/null 2>&1 &

# run transcoder
./scripts/loop-transcode.sh > /dev/null 2>&1 &

# run RTMP
./scripts/loop-rtmp.sh > /dev/null 2>&1 &

# run RTSP
./scripts/loop-rtsp.sh > /dev/null 2>&1 &

# run MPEG-TS
./scripts/loop-mpegts.sh > /dev/null 2>&1 &

# run TCP
./scripts/loop-tcp.sh > /dev/null 2>&1 &

#run menu display
./scripts/menu.sh > /dev/null 2>&1 &

# run receivers
./scripts/receiver-data.sh > /dev/null 2>&1 &
./scripts/receiver-video.sh > /dev/null 2>&1 &

# run WebSockets video bridge
cd ./wsbridge
./loop-ws-video.sh > /dev/null 2>&1 &
cd  ..

# run WebSockets data bridge
./scripts/ws-data.sh > /dev/null 2>&1 &

# run FTP proxy
cd ./ftp-proxy
./ftp-loop.sh > /dev/null 2>&1 &
cd  ..

# run internal camera
./scripts/camera.sh > /dev/null 2>&1 &

# run RC receiver
./scripts/rc.sh > /dev/null 2>&1 &

# run joystick
./scripts/joystick.sh > /dev/null 2>&1 &

# run onboard recording
./scripts/record.sh > /dev/null 2>&1 &

# run onboard recording watcher
./scripts/record-watcher.sh > /dev/null 2>&1 &

# clear HDMI console
setterm -clear all -foreground black -background black > /dev/tty0
setterm -clear all -foreground black -background black > /dev/tty3

# run main application loop
while [ 1 ] ; do
    ./bin/cosmostreamer >> /dev/null 2>&1

    # reboot if bad errors
    if  [ "$?" = "100" ]; then
	reboot
    fi

    killall -q data-receiver video-receiver joystick rcin
    sleep 1
done
